##  General Features of the Dashboard
The dashboard provides the following key capabilities:
  * KPI calculation: All KPIs are calculated on a daily basis and are archived in order to provide a KPI history. KPI values are therefore never older than 24 hours. You can click most KPIs in order to navigate to the Inventory and review the fact sheets that the KPI has been calculated on.


**Note**
Not all subsets of fact sheets used for KPI calculation can already be represented as a filter in the Inventory. This applies in particular to lifecycle filters. Therefore, there can be deviations between the subset of fact sheets based on which the KPI is calculated and the fact sheets displayed in the Inventory after clicking a KPI. Please note that these discrepancies do not affect the correctness of the KPI calculation. We are actively working on making these filters available in the Inventory as well.
  * Filters: All KPIs on the dashboard exclude applications that are "end of life", meaning that the application has reached the so-called lifecycle phase. The same holds true for any fact sheet that has quality seal "Draft" or "Rejected".
  * Configuration: As of now, the dashboards aren't editable. Users can create a copy of them and then edit the copies to their desire.
